@@ -4,5 +4,5 @@ from .drop import DropPath
 from .mlp import TransformerMLP
 from .attention import Attention
 from .mask import Mask
-from .patch_util import ExtractPatches, MergePatches, PatchEmbed
-from .pool import AdaptiveAveragePool1D
+from .patch_util import ExtractPatches, MergePatches, PatchEmbed, OverlapPatchEmbed
+from .pool import AdaptiveAveragePool1D, AdaptiveAveragePool2D
